@@ -27,6 +27,9 @@ class GogoDownload:
         self.series_generator = SeriesUrlGenerator(GOGO_URL)
         self.downloader = Downloader()
 
+    def extract_episode_urls(self, series_name):
+        return self.series_generator.find_episode_urls(series_name)
+
     def extract_episode_download_url(self, episode_url):
         # if (series_name, episode) in self.cache and cache:
         #    return DownloadLink(0, series_name, episode, self.cache[(series_name, episode)])
